@@ -1,7 +1,7 @@
 // drumkv1_controls.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -27,8 +27,6 @@
 
 #include <QMap>
 
-#include <math.h>
-
 
 //-------------------------------------------------------------------------
 // drumkv1_controls - Controller processs class.
@@ -185,7 +183,7 @@ protected:
 
 		void schedule_event(drumkv1::ParamIndex index, float value)
 		{
-			if (::fabsf(value - m_value) > 0.001f) {
+			if (qAbs(value - m_value) > 0.001f) {
 				m_value = value;
 				schedule(int(index));
 			}
