@@ -1,7 +1,7 @@
 // drumkv1_jack.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -601,7 +601,7 @@ void drumkv1_jack::sessionEvent ( void *pvSessionArg )
 		= QString::fromUtf8(pJackSessionEvent->session_dir);
 	const QString sSessionName
 		= QFileInfo(QFileInfo(sSessionDir).canonicalPath()).completeBaseName();
-	const QString sSessionFile = sSessionName + '.' + DRUMKV1_TITLE;
+	const QString sSessionFile = sSessionName + '.' + PROJECT_NAME;
 
 	QStringList args;
 	args << QCoreApplication::applicationFilePath();
@@ -747,7 +747,7 @@ static void drumkv1_sigterm_handler ( int /*signo*/ )
 // Constructor.
 drumkv1_jack_application::drumkv1_jack_application ( int& argc, char **argv )
 	: QObject(nullptr), m_pApp(nullptr), m_bGui(true),
-		m_sClientName(DRUMKV1_TITLE), m_pDrumk(nullptr), m_pWidget(nullptr)
+		m_sClientName(PROJECT_NAME), m_pDrumk(nullptr), m_pWidget(nullptr)
 	  #ifdef CONFIG_NSM
 		, m_pNsmClient(nullptr)
 	  #endif
@@ -773,11 +773,11 @@ drumkv1_jack_application::drumkv1_jack_application ( int& argc, char **argv )
 	#endif
 		QApplication *pApp = new QApplication(argc, argv);
 	#if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
-		pApp->setApplicationDisplayName(DRUMKV1_TITLE);
-		//	DRUMKV1_TITLE " - " + QObject::tr(DRUMKV1_SUBTITLE));
+		pApp->setApplicationDisplayName(PROJECT_NAME);
+		//	PROJECT_NAME " - " + QObject::tr(PROJECT_DESCRIPTION));
 	#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
 		pApp->setDesktopFileName(
-			QString("org.rncbc.%1").arg(PACKAGE_TARNAME));
+			QString("org.rncbc.%1").arg(PROJECT_NAME));
 	#endif
 	#endif
 		m_pApp = pApp;
@@ -786,8 +786,8 @@ drumkv1_jack_application::drumkv1_jack_application ( int& argc, char **argv )
 	}
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
-	m_pApp->setApplicationName(DRUMKV1_TITLE);
-	QString sVersion(CONFIG_BUILD_VERSION);
+	m_pApp->setApplicationName(PROJECT_NAME);
+	QString sVersion(PROJECT_VERSION);
 	sVersion += '\n';
 	sVersion += QString("Qt: %1").arg(qVersion());
 #if defined(QT_STATIC)
@@ -875,17 +875,17 @@ bool drumkv1_jack_application::parse_args (void)
 
 	QCommandLineParser parser;
 	parser.setApplicationDescription(
-		DRUMKV1_TITLE " - " + QObject::tr(DRUMKV1_SUBTITLE));
+		PROJECT_NAME " - " + QObject::tr(PROJECT_DESCRIPTION));
 
 	parser.addOption({{"g", "no-gui"},
 		QObject::tr("Disable the graphical user interface (GUI)")});
 	parser.addOption({{"n", "client-name"},
 		QObject::tr("Set the JACK client name (default: %1)")
-			.arg(DRUMKV1_TITLE), "label"});
+			.arg(PROJECT_NAME), "label"});
 	parser.addHelpOption();
 	parser.addVersionOption();
 	parser.addPositionalArgument("preset-file",
-		QObject::tr("Load preset file (.%1)").arg(DRUMKV1_TITLE),
+		QObject::tr("Load preset file (.%1)").arg(PROJECT_NAME),
 		QObject::tr("[preset-file]"));
 	parser.process(args);
 
@@ -902,7 +902,7 @@ bool drumkv1_jack_application::parse_args (void)
 		m_sClientName = sVal;
 	}
 
-	foreach(const QString& sArg, parser.positionalArguments()) {
+	foreach (const QString& sArg, parser.positionalArguments()) {
 		m_presets.append(sArg);
 	}
 
@@ -941,12 +941,12 @@ bool drumkv1_jack_application::parse_args (void)
 			const QString sEot = "\n\t";
 			const QString sEol = "\n\n";
 			out << QObject::tr("Usage: %1 [options]").arg(args.at(0)) + sEol;
-			out << DRUMKV1_TITLE " - " << QObject::tr(DRUMKV1_SUBTITLE) + sEol;
+			out << PROJECT_NAME " - " << QObject::tr(PROJECT_DESCRIPTION) + sEol;
 			out << QObject::tr("Options:") + sEol;
 			out << "  -g, --no-gui" + sEot +
 				QObject::tr("Disable the graphical user interface (GUI)") + sEol;
 			out << "  -n, --client-name=[label]" + sEot +
-				QObject::tr("Set the JACK client name (default: %1)").arg(DRUMKV1_TITLE) + sEol;
+				QObject::tr("Set the JACK client name (default: %1)").arg(PROJECT_NAME) + sEol;
 			out << "  -h, --help" + sEot +
 				QObject::tr("Show help about command line options.") + sEol;
 			out << "  -v, --version" + sEot +
@@ -961,8 +961,8 @@ bool drumkv1_jack_application::parse_args (void)
 		#endif
 			out << '\n';
 			out << QString("%1: %2\n")
-				.arg(DRUMKV1_TITLE)
-				.arg(CONFIG_BUILD_VERSION);
+				.arg(PROJECT_NAME)
+				.arg(PROJECT_VERSION);
 			return false;
 		}
 		else {
@@ -1033,7 +1033,7 @@ bool drumkv1_jack_application::setup (void)
 		QString caps(":switch:dirty:");
 		if (m_bGui)
 			caps += "optional-gui:";
-		m_pNsmClient->announce(DRUMKV1_TITLE, caps.toLocal8Bit().constData());
+		m_pNsmClient->announce(PROJECT_NAME, caps.toLocal8Bit().constData());
 		if (m_pWidget)
 			m_pWidget->setNsmClient(m_pNsmClient);
 	}
@@ -1089,9 +1089,9 @@ void drumkv1_jack_application::openSession (void)
 
 	bool bOpen = false;
 
-	QFileInfo fi(path_name, "session." DRUMKV1_TITLE);
+	QFileInfo fi(path_name, "session." PROJECT_NAME);
 	if (!fi.exists())
-		fi.setFile(path_name, display_name + '.' + DRUMKV1_TITLE);
+		fi.setFile(path_name, display_name + '.' + PROJECT_NAME);
 	if (fi.exists()) {
 		const QString& sFilename = fi.absoluteFilePath();
 		if (m_pWidget) {
@@ -1128,8 +1128,8 @@ void drumkv1_jack_application::saveSession (void)
 //	const QString& client_name = m_pNsmClient->client_name();
 	const QString& path_name = m_pNsmClient->path_name();
 //	const QString& display_name = m_pNsmClient->display_name();
-//	const QFileInfo fi(path_name, display_name + '.' + DRUMKV1_TITLE);
-	const QFileInfo fi(path_name, "session." DRUMKV1_TITLE);
+//	const QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
+	const QFileInfo fi(path_name, "session." PROJECT_NAME);
 
 	const bool bSave
 		= drumkv1_param::savePreset(m_pDrumk, fi.absoluteFilePath(), true);
