@@ -1,7 +1,7 @@
 // drumkv1_lv2.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -29,18 +29,28 @@
 #include "drumkv1_programs.h"
 #include "drumkv1_controls.h"
 
+#ifdef CONFIG_LV2_OLD_HEADERS
 #include "lv2/lv2plug.in/ns/ext/midi/midi.h"
 #include "lv2/lv2plug.in/ns/ext/time/time.h"
 #include "lv2/lv2plug.in/ns/ext/atom/util.h"
-
 #include "lv2/lv2plug.in/ns/ext/state/state.h"
-
 #include "lv2/lv2plug.in/ns/ext/options/options.h"
 #include "lv2/lv2plug.in/ns/ext/buf-size/buf-size.h"
-
 #ifdef CONFIG_LV2_PATCH
 #include "lv2/lv2plug.in/ns/ext/patch/patch.h"
 #endif
+#else
+#include "lv2/midi/midi.h"
+#include "lv2/time/time.h"
+#include "lv2/atom/util.h"
+#include "lv2/state/state.h"
+#include "lv2/options/options.h"
+#include "lv2/buf-size/buf-size.h"
+#ifdef CONFIG_LV2_PATCH
+#include "lv2/patch/patch.h"
+#endif
+#endif
+
 
 #ifndef CONFIG_LV2_ATOM_FORGE_OBJECT
 #define lv2_atom_forge_object(forge, frame, id, otype) \
@@ -81,12 +91,20 @@ public:
 
 	drumkv1_lv2_map_path(const LV2_Feature *const *features)
 		: m_map_path(nullptr)
+	#ifdef CONFIG_LV2_STATE_FREE_PATH
+		, m_free_path(nullptr)
+	#endif
 	{
 		for (int i = 0; features && features[i]; ++i) {
-			if (::strcmp(features[i]->URI, LV2_STATE__mapPath) == 0) {
+			if (m_map_path == nullptr
+				&& ::strcmp(features[i]->URI, LV2_STATE__mapPath) == 0)
 				m_map_path = (LV2_State_Map_Path *) features[i]->data;
-				break;
-			}
+		#ifdef CONFIG_LV2_STATE_FREE_PATH
+			else
+			if (m_free_path == nullptr
+				&& ::strcmp(features[i]->URI, LV2_STATE__freePath) == 0)
+				m_free_path = (LV2_State_Free_Path *) features[i]->data;
+		#endif
 		}
 	}
 
@@ -99,6 +117,13 @@ public:
 					m_map_path->handle, sAbstractPath.toUtf8().constData());
 			if (pszAbsolutePath) {
 				sAbsolutePath = QString::fromUtf8(pszAbsolutePath);
+			#ifdef CONFIG_LV2_STATE_FREE_PATH
+				if (m_free_path) {
+					m_free_path->free_path(
+						m_free_path->handle, (char *) pszAbsolutePath);
+				}
+				else
+			#endif
 				::free((void *) pszAbsolutePath);
 			}
 		}
@@ -114,6 +139,13 @@ public:
 					m_map_path->handle, sAbsolutePath.toUtf8().constData());
 			if (pszAbstractPath) {
 				sAbstractPath = QString::fromUtf8(pszAbstractPath);
+			#ifdef CONFIG_LV2_STATE_FREE_PATH
+				if (m_free_path) {
+					m_free_path->free_path(
+						m_free_path->handle, (char *) pszAbstractPath);
+				}
+				else
+			#endif
 				::free((void *) pszAbstractPath);
 			}
 		}
@@ -122,7 +154,10 @@ public:
 
 private:
 
-	LV2_State_Map_Path *m_map_path;
+	LV2_State_Map_Path  *m_map_path;
+#ifdef CONFIG_LV2_STATE_FREE_PATH
+	LV2_State_Free_Path *m_free_path;
+#endif
 };
 
 
@@ -152,6 +187,10 @@ drumkv1_lv2::drumkv1_lv2 (
 	m_schedule = nullptr;
 	m_ndelta   = 0;
 
+#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+	m_port_change_request = nullptr;
+#endif
+
 	const LV2_Options_Option *host_options = nullptr;
 
 	for (int i = 0; host_features && host_features[i]; ++i) {
@@ -241,6 +280,11 @@ drumkv1_lv2::drumkv1_lv2 (
 		else
 		if (::strcmp(host_feature->URI, LV2_OPTIONS__options) == 0)
 			host_options = (const LV2_Options_Option *) host_feature->data;
+	#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+		else
+		if (::strcmp(host_feature->URI, LV2_CONTROL_INPUT_PORT_CHANGE_REQUEST_URI) == 0)
+			m_port_change_request = (LV2_ControlInputPort_Change_Request *) host_feature->data;
+	#endif
 	}
 
 	uint32_t buffer_size = 1024; // maybe some safe default?
@@ -520,7 +564,7 @@ void drumkv1_lv2::qapp_instantiate (void)
 {
 	if (qApp == nullptr && g_qapp_instance == nullptr) {
 		static int s_argc = 1;
-		static const char *s_argv[] = { DRUMKV1_TITLE, nullptr };
+		static const char *s_argv[] = { PROJECT_NAME, nullptr };
 	#if defined(WIN32) || defined(_WIN32) || defined(__WIN32)
 		::_putenv_s("QT_NO_GLIB", "1"); // Avoid glib event-loop...
 	#else
@@ -585,7 +629,7 @@ static LV2_State_Status drumkv1_lv2_state_save ( LV2_Handle instance,
 #endif
 	drumkv1_lv2_map_path mapPath(features);
 
-	QDomDocument doc(DRUMKV1_TITLE);
+	QDomDocument doc(PROJECT_NAME);
 	QDomElement eState = doc.createElement("state");
 
 	QDomElement eElements = doc.createElement("elements");
@@ -647,7 +691,7 @@ static LV2_State_Status drumkv1_lv2_state_restore ( LV2_Handle instance,
 
 	drumkv1_lv2_map_path mapPath(features);
 
-	QDomDocument doc(DRUMKV1_TITLE);
+	QDomDocument doc(PROJECT_NAME);
 	if (doc.setContent(QByteArray(value, size))) {
 		QDomElement eState = doc.documentElement();
 	#if 1//DRUMKV1_LV2_LEGACY
@@ -738,6 +782,11 @@ void drumkv1_lv2::updatePreset ( bool /*bDirty*/ )
 
 void drumkv1_lv2::updateParam ( drumkv1::ParamIndex index )
 {
+#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+	if (port_change_request(index))
+		return;
+#endif
+
 #ifdef CONFIG_LV2_PORT_EVENT
 	if (m_schedule) {
 		drumkv1_lv2_worker_message mesg;
@@ -747,14 +796,17 @@ void drumkv1_lv2::updateParam ( drumkv1::ParamIndex index )
 		m_schedule->schedule_work(
 			m_schedule->handle, sizeof(mesg), &mesg);
 	}
-#else
-	(void) index; // STFU dang compiler!
 #endif
 }
 
 
 void drumkv1_lv2::updateParams (void)
 {
+#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+	if (port_change_requests())
+		return;
+#endif
+
 #ifdef CONFIG_LV2_PORT_EVENT
 	if (m_schedule) {
 		drumkv1_lv2_worker_message mesg;
@@ -1030,6 +1082,48 @@ bool drumkv1_lv2::port_events ( uint32_t nparams )
 #endif	// CONFIG_LV2_PORT_EVENT
 
 
+#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+
+bool drumkv1_lv2::port_change_request ( drumkv1::ParamIndex index )
+{
+	if (m_port_change_request == nullptr)
+		return false;
+	if (m_port_change_request->handle == nullptr)
+		return false;
+	if (m_port_change_request->request_change == nullptr)
+		return false;
+
+	return m_port_change_request->request_change(
+		m_port_change_request->handle,
+		uint32_t(ParamBase + index),
+		drumkv1::paramValue(index))
+		== LV2_CONTROL_INPUT_PORT_CHANGE_SUCCESS;
+}
+
+
+bool drumkv1_lv2::port_change_requests (void)
+{
+	if (m_port_change_request == nullptr)
+		return false;
+	if (m_port_change_request->handle == nullptr)
+		return false;
+	if (m_port_change_request->request_change == nullptr)
+		return false;
+
+	for (uint32_t i = 0; i < drumkv1::NUM_PARAMS; ++i) {
+		drumkv1::ParamIndex index = drumkv1::ParamIndex(i);
+		m_port_change_request->request_change(
+			m_port_change_request->handle,
+			uint32_t(ParamBase + index),
+			drumkv1::paramValue(index));
+	}
+
+	return true;
+}
+
+#endif	// CONFIG_LV2_PORT_CHANGE_REQUEST
+
+
 //-------------------------------------------------------------------------
 // drumkv1_lv2 - LV2 desc.
 //
