@@ -1,7 +1,7 @@
 // drumkv1_param.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -376,7 +376,7 @@ bool drumkv1_param::loadPreset (
 	const QDir currentDir(QDir::current());
 	QDir::setCurrent(fi.absolutePath());
 
-	QDomDocument doc(DRUMKV1_TITLE);
+	QDomDocument doc(PROJECT_NAME);
 	if (doc.setContent(&file)) {
 		QDomElement ePreset = doc.documentElement();
 		if (ePreset.tagName() == "preset") {
@@ -445,10 +445,10 @@ bool drumkv1_param::savePreset (
 	const QDir currentDir(QDir::current());
 	QDir::setCurrent(fi.absolutePath());
 
-	QDomDocument doc(DRUMKV1_TITLE);
+	QDomDocument doc(PROJECT_NAME);
 	QDomElement ePreset = doc.createElement("preset");
 	ePreset.setAttribute("name", fi.completeBaseName());
-	ePreset.setAttribute("version", CONFIG_BUILD_VERSION);
+	ePreset.setAttribute("version", PROJECT_VERSION);
 
 	QDomElement eElements = doc.createElement("elements");
 	drumkv1_param::saveElements(pDrumk, doc, eElements, map_path(), bSymLink);
